==> crowdstrike-falconpy-1.3.2.tar.gz: crowdstrike-falconpy-1.3.2/src/falconpy/_error/__init__.py <==
"""FalconPy error module.

 _______                        __ _______ __        __ __
|   _   .----.-----.--.--.--.--|  |   _   |  |_.----|__|  |--.-----.
|.  1___|   _|  _  |  |  |  |  _  |   1___|   _|   _|  |    <|  -__|
|.  |___|__| |_____|________|_____|____   |____|__| |__|__|__|_____|
|:  1   |                         |:  1   |
|::.. . |   CROWDSTRIKE FALCON    |::.. . |    FalconPy
`-------'                         `-------'

OAuth2 API - Customer SDK

This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any
means.

In jurisdictions that recognize copyright laws, the author or authors
of this software dedicate any and all copyright interest in the
software to the public domain. We make this dedication for the benefit
of the public at large and to the detriment of our heirs and
successors. We intend this dedication to be an overt act of
relinquishment in perpetuity of all present and future rights to this
software under copyright law.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

For more information, please refer to <https://unlicense.org>
"""
from ._exceptions import (
    SDKError,
    RegionSelectError,
    InvalidMethod,
    InvalidOperation,
    TokenNotSpecified,
    KeywordsOnly,
    InvalidCredentials,
    APIError,
    CannotRevokeToken,
    FunctionalityNotImplemented,
    InvalidBaseURL,
    PayloadValidationError,
    FeatureNotSupportedByPythonVersion,
    InvalidIndex,
    InvalidCredentialFormat
    )
from ._warnings import (
    SDKWarning,
    SSLDisabledWarning,
    NoContentWarning,
    NoAuthenticationMechanism,
    UnnecessaryEncodingUsed
)


__all__ = ["SDKError", "RegionSelectError", "InvalidMethod", "InvalidOperation",
           "TokenNotSpecified", "KeywordsOnly", "SDKWarning", "SSLDisabledWarning",
           "InvalidCredentials", "APIError", "NoContentWarning", "CannotRevokeToken",
           "FunctionalityNotImplemented", "InvalidBaseURL", "PayloadValidationError",
           "NoAuthenticationMechanism", "FeatureNotSupportedByPythonVersion",
           "InvalidIndex", "InvalidCredentialFormat", "UnnecessaryEncodingUsed"
           ]

==> crowdstrike-falconpy-1.4.2.tar.gz: crowdstrike-falconpy-1.4.2/src/falconpy/_error/__init__.py <==
"""FalconPy error module.

 _______                        __ _______ __        __ __
|   _   .----.-----.--.--.--.--|  |   _   |  |_.----|__|  |--.-----.
|.  1___|   _|  _  |  |  |  |  _  |   1___|   _|   _|  |    <|  -__|
|.  |___|__| |_____|________|_____|____   |____|__| |__|__|__|_____|
|:  1   |                         |:  1   |
|::.. . |   CROWDSTRIKE FALCON    |::.. . |    FalconPy
`-------'                         `-------'

OAuth2 API - Customer SDK

This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any
means.

In jurisdictions that recognize copyright laws, the author or authors
of this software dedicate any and all copyright interest in the
software to the public domain. We make this dedication for the benefit
of the public at large and to the detriment of our heirs and
successors. We intend this dedication to be an overt act of
relinquishment in perpetuity of all present and future rights to this
software under copyright law.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

For more information, please refer to <https://unlicense.org>
"""
from ._exceptions import (
    SDKError,
    RegionSelectError,
    InvalidMethod,
    InvalidOperation,
    TokenNotSpecified,
    KeywordsOnly,
    InvalidCredentials,
    APIError,
    CannotRevokeToken,
    FunctionalityNotImplemented,
    InvalidBaseURL,
    PayloadValidationError,
    FeatureNotSupportedByPythonVersion,
    InvalidIndex,
    InvalidCredentialFormat
    )
from ._warnings import (
    SDKWarning,
    SSLDisabledWarning,
    NoContentWarning,
    NoAuthenticationMechanism,
    UnnecessaryEncodingUsed,
    SDKDeprecationWarning,
    DeprecatedOperation,
    DeprecatedClass
)


__all__ = ["SDKError", "RegionSelectError", "InvalidMethod", "InvalidOperation",
           "TokenNotSpecified", "KeywordsOnly", "SDKWarning", "SSLDisabledWarning",
           "InvalidCredentials", "APIError", "NoContentWarning", "CannotRevokeToken",
           "FunctionalityNotImplemented", "InvalidBaseURL", "PayloadValidationError",
           "NoAuthenticationMechanism", "FeatureNotSupportedByPythonVersion",
           "InvalidIndex", "InvalidCredentialFormat", "UnnecessaryEncodingUsed",
           "SDKDeprecationWarning", "DeprecatedOperation", "DeprecatedClass"
           ]
